@@ -1,6 +1,6 @@
 #!/bin/bash
 
-script_root=$(dirname $(realpath $(which $0)))
+script_root=$(dirname "$0")/../share/rclip
 if [ "$1" = "image" ]; then
     source $script_root/feh_pick_image.sh
 else
