@@ -1,10 +1,10 @@
 #!/bin/bash
 
-RCLIP_HOME="$HOME/.rclip"
+RCLIP_HOME="${XDG_DATA_HOME:-$HOME/.local/share}/rclip"
 
 export PICK_PURPOSE="copy"
 
-script_root=$(dirname $(realpath $(which $0)))
+script_root=$(dirname "$0")/../share/rclip
 source $script_root/_pick.sh
 
 # send a signal to rclip that now we will set entry from history
